.title Overview

Harfang is a high-level software library to create applications that display 2D/3D visuals and play sound/music.

It provides a unified API to write programs using different programming languages and is available for Windows and Linux. For more details, see [man.Requirements].

## Supported Programming Languages

The installation instructions for each supported language are found in the following manual pages:

* [man.CPython]
* [man.Lua]

## Getting Help

* For generic programming issues:
	- [Stack Overflow](http://stackoverflow.com/)
* For game development related issues:
	- [gamedev.net](http://www.gamedev.net)
